@@ -112,7 +112,7 @@ xapp_util_get_session_is_running (void)
  *
  * Converts a pango font description string to a string suitable for use with the css "font" tag. The font description must contain the font family and font size or conversion will fail and %NULL will be returned
  *
- * Returns: (transfer full) the css compatible font string or %NULL if the conversion failed.
+ * Returns: (transfer full): the css compatible font string or %NULL if the conversion failed.
  *
  * Since: 2.2
  */
@@ -245,3 +245,33 @@ xapp_pango_font_string_to_css (const char *pango_font_string)
 
     return g_string_free (font_string, FALSE);
 }
+
+
+/**
+ * xapp_get_tmp_dir:
+ *
+ * Provides the path to the system's temporary files folder. This is identical to g_get_tmp_dir,
+ * but includes the /dev/shm ramdisk as the first choice for a temporary folder.
+ * 
+ * Returns: (type filename) (transfer none): the directory to use for temporary files.
+ * Since: 2.2.16
+ */
+const gchar *
+xapp_get_tmp_dir (void)
+{
+    static const gchar *tmp_dir = NULL;
+
+    if (tmp_dir == NULL)
+    {
+        if (access ("/dev/shm", W_OK) == 0)
+        {
+            tmp_dir = "/dev/shm";
+        }
+        else
+        {
+            tmp_dir = g_get_tmp_dir ();
+        }
+    }
+
+    return tmp_dir;
+}
